@@ -1,6 +1,6 @@
 use nxui::io::storage::Storage;
 use nxui::natives_and_messaging::{ADVANCED_WINDOWSTYLE_UTILITY, WINDOWSTYLE_NORMAL};
-use nxui::window::{AdvancedOptions, Application, Frame, WindowAttributes};
+use nxui::window::{AdvancedOptions, Application, Frame, Attributes};
 
 fn main() {
     let app = UtilityApplication::new();
@@ -24,8 +24,8 @@ impl Application for UtilityApplication {
         "Utility App".to_string()
     }
 
-    fn attributes(&self) -> WindowAttributes {
-        WindowAttributes::new(WINDOWSTYLE_NORMAL, "Utility Window".to_string(),400, 675, 100, 100,false)
+    fn attributes(&self) -> Attributes {
+        Attributes::new(WINDOWSTYLE_NORMAL, "Utility Window".to_string(),400, 675, 100, 100)
     }
 
     fn advanced_options(&self) -> AdvancedOptions {
