@@ -1,9 +1,5 @@
-use nxui::messagebox::MessageBox;
 use nxui::util::*;
-use nxui::natives_and_messaging::*;
 use nxui::window::demowindow::DemoWindow;
-use nxui::window::Frame;
-
 fn main() {
     let win = DemoWindow::new();
     println!("{}",get_run_dir());
