@@ -24,6 +24,10 @@ impl Application for DemoWindow {
         Attributes::new(WINDOWSTYLE_NORMAL, "NXUI Window".to_string(),1280, 750, 100, 100)
     }
 
+    fn is_child_window(&self) -> bool {
+        false
+    }
+
     fn startup(&self,storage: Storage) {
         println!("Startup!");
         println!("Config dir is {}",storage.get_config_dir().as_os_str().to_str().unwrap());
@@ -31,20 +35,6 @@ impl Application for DemoWindow {
 
     fn ui(&self,frame: Frame) {
         frame.show();
-        match MessageBox::new("Do you want to maximize the window?".to_string(), "Do you want to maximize the window?".to_string(), DIALOGSTYLE_QUESTION, BUTTONSTYLE_YESNO).show(Frame::default()) {
-            RESULTS_YES => {
-                frame.show_maximized();
-                frame.set_title("The window has been maximized.".to_string());
-            }
-
-            RESULTS_NO => {
-                frame.show_minimized();
-                frame.set_title("The window has been minimized.".to_string());
-            }
-
-            _ => {}
-        }
-        frame.set_size(500,720);
     }
 
     fn exit(&self) {
