@@ -1,6 +1,7 @@
 //! Provides traits and tools for displaying windows.
 
 use crate::io::storage::Storage;
+use crate::widget::NWidget;
 
 pub mod demowindow;
 
@@ -20,6 +21,11 @@ impl Frame {
         }
     }
 
+    /// Add a widget to the window
+    pub fn add(&self,widget: &dyn NWidget,frame: Frame) {
+
+    }
+
     /// Display the window
     pub fn show(&self) {
         use windows_sys::Win32::UI::WindowsAndMessaging::ShowWindow;
@@ -123,13 +129,11 @@ impl Attributes {
 }
 
 #[cfg(windows)]
-#[cfg(feature="nxui-awc")]
 pub struct AdvancedOptions {
     advanced_style: windows_sys::Win32::UI::WindowsAndMessaging::WINDOW_EX_STYLE
 }
 
 #[cfg(windows)]
-#[cfg(feature="nxui-awc")]
 impl AdvancedOptions {
     pub fn new(advanced_style: windows_sys::Win32::UI::WindowsAndMessaging::WINDOW_EX_STYLE) -> Self {
         Self {
@@ -143,7 +147,6 @@ impl AdvancedOptions {
 }
 
 #[cfg(windows)]
-#[cfg(feature="nxui-awc")]
 impl Default for AdvancedOptions {
     fn default() -> Self {
         Self {
@@ -159,7 +162,8 @@ pub trait Application {
     /// Returns WindowAttributes.
     fn attributes(&self) -> Attributes;
 
-    #[cfg(feature="nxui-awc")]
+    fn is_child_window(&self) -> bool;
+
     fn advanced_options(&self) -> AdvancedOptions {
         AdvancedOptions::default()
     }
@@ -274,13 +278,11 @@ impl Attributes {
 }
 
 #[cfg(unix)]
-#[cfg(feature="nxui-awc")]
 pub struct AdvancedOptions {
     advanced_style: gtk::gdk::WindowTypeHint
 }
 
 #[cfg(unix)]
-#[cfg(feature="nxui-awc")]
 impl AdvancedOptions {
     pub fn new(advanced_style: gtk::gdk::WindowTypeHint) -> Self {
         Self {
@@ -294,7 +296,6 @@ impl AdvancedOptions {
 }
 
 #[cfg(unix)]
-#[cfg(feature="nxui-awc")]
 impl Default for AdvancedOptions {
     fn default() -> Self {
         Self {
